@@ -1,14 +1,14 @@
 print.netconnection <- function(x,
-                                digits = max(4, .Options$digits - 3), ...){
+                                digits = max(4, .Options$digits - 3), ...) {
   
   meta:::chknumeric(digits, single = TRUE)
   
   
   matitle(x)
   ##
-  cat(paste("Number of studies: k = ", x$k, "\n", sep=""))
-  cat(paste("Number of treatments: n = ", x$n, "\n", sep=""))
-  cat(paste("Number of pairwise comparisons: m = ", x$m, "\n", sep=""))
+  cat(paste("Number of studies: k = ", x$k, "\n", sep = ""))
+  cat(paste("Number of treatments: n = ", x$n, "\n", sep = ""))
+  cat(paste("Number of pairwise comparisons: m = ", x$m, "\n", sep = ""))
   ##
   cat("Number of networks: ", x$n.subnets, "\n\n", sep = "")
   
@@ -16,6 +16,8 @@ print.netconnection <- function(x,
 
   D <- round(x$D.matrix, digits = digits)
   D[is.infinite(D)] <- "."
+  if (x$n.subnets == 1)
+    diag(D) <- "."
   prmatrix(D, quote = FALSE, right = TRUE)
   
   invisible(NULL)
