@@ -51,8 +51,10 @@ summary.netmeta <- function(object,
               fixed = ci.f, random = ci.r,
               studies = object$studies,
               narms = object$narms,
-              k = k, m = m, n = n, Q = Q, df = object$df,
+              k = k, m = m, n = n, d = object$d,
+              Q = Q, df = object$df,
               tau = object$tau, I2 = object$I2,
+              tau.preset = object$tau.preset,
               sm = object$sm,
               ci.lab = ci.lab,
               comb.fixed = comb.fixed,
